<?php
# install en-gb without XML-RPC requirements
$en_gb_lang = array(
	'admin' => array(
		'add_new_author' => 'Add New Author',
		'and_mailed_to' => 'and mailed to',
		'assign_assets_to' => 'Assign user’s content to',
		'author_deleted' => 'Author <strong>{name}</strong> deleted.',
		'author_updated' => 'Author <strong>{name}</strong> updated.',
		'a_message_will_be_sent_with_login' => 'A message will be sent with login information.',
		'a_new_password_will_be_mailed' => 'A new password will be e-mailed',
		'changeprivilege' => 'Change privilege',
		'change_email_address' => 'Change Your E-mail Address',
		'change_password' => 'Change Your Password',
		'copy_editor' => 'Copy Editor',
		'could_not_mail' => 'Could not mail',
		'could_not_update_author' => 'Could not update author',
		'designer' => 'Designer',
		'edit_author' => 'Edit Author',
		'email_changed' => 'E-mail address changed to {email}.',
		'error_adding_new_author' => 'Error adding new author.',
		'freelancer' => 'Freelancer',
		'last_login' => 'Last Login',
		'login_name' => 'Login',
		'log_in_at' => 'Login at',
		'mail_it' => 'Mail it to me',
		'managing_editor' => 'Managing Editor',
		'must_reassign_assets' => 'Please re-assign user’s content',
		'new_email' => 'New e-mail',
		'new_password' => 'New password',
		'password_changed' => 'Password changed',
		'password_changed_mailed' => 'Password changed and mailed to {email}.',
		'password_forgotten' => 'Forgot password?',
		'password_required' => 'Please provide a new password.',
		'password_reset' => 'Reset password',
		'password_reset_button' => 'Reset password',
		'password_reset_confirmation' => 'Somebody (probably you) has requested to reset your password. Please confirm this reset request by clicking on the link below',
		'password_reset_confirmation_request' => 'Please confirm your password reset request',
		'password_reset_confirmation_request_sent' => 'A confirmation message was sent to your e-mail address. <br />Please check your email and follow the instructions.',
		'password_sent_to' => 'Password sent to',
		'privileges' => 'Privileges',
		'publisher' => 'Publisher',
		'real_name' => 'Real Name',
		'resetpassword' => 'Reset password',
		'reset_author_password' => 'Reset author password',
		'site_administration' => 'Users',
		'staff_writer' => 'Staff writer',
		'unknown_author' => 'Unknown author: {name}',
		'writer' => 'Writer',
		'your_login_info' => 'Your login info',
		'your_login_is' => 'Your login is',
		'your_new_password' => 'Your new password',
		'your_password_is' => 'Your password is',
		'you_have_been_registered' => 'You have been registered as a contributor to the site',
	),
	'article' => array(
		'advanced_options' => 'Advanced Options',
		'article_day' => 'Day',
		'article_expires_before_postdate' => 'Error: Article expires <strong>before</strong> post date.',
		'article_hour' => 'Hour',
		'article_image' => 'Article image',
		'article_markup' => 'Article Markup',
		'article_minute' => 'Minute',
		'article_month' => 'Month',
		'article_posted' => 'Article posted.',
		'article_saved' => 'Article saved.',
		'article_saved_draft' => 'Article saved as draft.',
		'article_saved_hidden' => 'Article saved as hidden.',
		'article_saved_pending' => 'Article saved as pending.',
		'article_second' => 'Second',
		'article_year' => 'Year',
		'concurrent_edit_by' => 'Article NOT saved. {author} modified the article while you were editing it. If you\'re sure, press the \'save\' button once more.',
		'excerpt_markup' => 'Excerpt Markup',
		'expires' => 'Expires',
		'no_articles_recorded' => 'No articles recorded.',
		'or_publish_at' => '&#8230;or publish at',
		'override_default_form' => 'Override form',
		'pending' => 'Pending',
		'reset_time' => 'Reset time to now&#8230;',
		'set_to_now' => 'Set timestamp to now&#8230;',
		'sort_display' => 'Sort and Display',
		'timestamp' => 'Timestamp',
		'url_title' => 'URL-only title',
		'url_title_is_blank' => 'URL-only title was left blank.',
		'url_title_is_multiple' => 'The same URL-only title is used by {count} different articles.',
		'write' => 'Write',
	),
	'category' => array(
		'article_categories_deleted' => 'Article categories deleted: <strong>{list}</strong>.',
		'article_category' => 'Article category',
		'article_category_already_exists' => 'Article category <strong>{name}</strong> already exists.',
		'article_category_created' => 'Article category <strong>{name}</strong> created.',
		'article_category_invalid' => 'Article category <strong>{name}</strong> invalid.',
		'article_category_name' => 'Article category name',
		'article_category_title' => 'Article category title',
		'article_category_updated' => 'Article category <strong>{name}</strong> updated.',
		'article_head' => 'Article Categories',
		'edit_category' => 'Edit Category',
		'file_categories_deleted' => 'File categories deleted: <strong>{list}</strong>.',
		'file_category_already_exists' => 'File category <strong>{name}</strong> already exists.',
		'file_category_created' => 'File category <strong>{name}</strong> created.',
		'file_category_invalid' => 'File category <strong>{name}</strong> invalid.',
		'file_category_name' => 'File Category name',
		'file_category_title' => 'File Category title',
		'file_category_updated' => 'File category <strong>{name}</strong> updated.',
		'file_head' => 'File Categories',
		'image_categories_deleted' => 'Image categories deleted: <strong>{list}</strong>.',
		'image_category_already_exists' => 'Image category <strong>{name}</strong> already exists.',
		'image_category_created' => 'Image category <strong>{name}</strong> created.',
		'image_category_invalid' => 'Image category <strong>{name}</strong> invalid.',
		'image_category_name' => 'Image Category name',
		'image_category_title' => 'Image category title',
		'image_category_updated' => 'Image category <strong>{name}</strong> updated.',
		'image_head' => 'Image Categories',
		'link_categories_deleted' => 'Link categories deleted: <strong>{list}</strong>.',
		'link_category_already_exists' => 'Link category <strong>{name}</strong> already exists.',
		'link_category_created' => 'Link category <strong>{name}</strong> created.',
		'link_category_invalid' => 'Link category <strong>{name}</strong> invalid.',
		'link_category_name' => 'Link Category name',
		'link_category_title' => 'Link Category title',
		'link_category_updated' => 'Link category <strong>{name}</strong> updated.',
		'link_head' => 'Link Categories',
		'no_categories_exist' => 'None exist.',
		'no_other_categories_exist' => 'No other categories exist.',
		'parent' => 'Parent',
	),
	'common' => array(
		'active' => 'Active',
		'add' => 'Add',
		'admin' => 'Admin',
		'ar-ar' => 'عربي',
		'ar-dz' => 'عربي',
		'are_you_sure' => 'Are you sure?',
		'ascending' => 'Ascending',
		'auth_required' => 'Authorisation required.',
		'bad_cookie' => 'Your login session has expired. Please login again.',
		'bg-bg' => 'Български',
		'body' => 'Body',
		'ca-es' => 'Català',
		'cannot_instantiate_theme' => 'Theme <strong>{name}</strong> ({class}) fails to load properly from file {path}. The Classic theme will be used as a fall-back.',
		'changeauthor' => 'Change author',
		'changecategory' => 'Change category',
		'changecategory1' => 'Change category1',
		'changecategory2' => 'Change category2',
		'changecomments' => 'Change comments',
		'changesection' => 'Change section',
		'changestatus' => 'Change status',
		'confirm_delete_popup' => 'Really delete?',
		'cookies_must_be_enabled' => 'Browser cookies must be enabled to use Textpattern.',
		'could_not_log_in' => 'Could not login with that name/password.',
		'cs-cz' => 'Čeština',
		'da-dk' => 'Dansk',
		'de-de' => 'Deutsch',
		'delete_selected' => 'Delete selected',
		'descending' => 'Descending',
		'description' => 'Description',
		'detail_toggle' => 'Show Detail',
		'draft' => 'Draft',
		'el-gr' => 'Ελληνικά',
		'en-gb' => 'English (Great Britain)',
		'en-us' => 'English (United States)',
		'es-es' => 'Español',
		'et-ee' => 'Eesti',
		'excerpt' => 'Excerpt',
		'expired' => 'Expired',
		'fi-fi' => 'Suomi',
		'form_not_found' => 'Form not found',
		'form_not_specified' => 'Form not specified.',
		'fr-fr' => 'Français',
		'gd_unavailable' => 'unavailable',
		'gl-gz' => 'Galego',
		'greeting' => 'Dear',
		'he-il' => 'עברית',
		'hidden' => 'Hidden',
		'hr-hr' => 'Hrvatski',
		'hu-hu' => 'Magyar',
		'id-id' => 'Bahasa Indonesia',
		'image_category' => 'Category',
		'is-is' => 'Íslenska',
		'it-it' => 'Italiano',
		'ja-jp' => '日本語',
		'ko-kr' => '한국말 (대한민국)',
		'lang_dir' => 'ltr',
		'link_category' => 'Category',
		'logged_in_as' => 'Logged in as',
		'login' => 'Login',
		'login_to_textpattern' => 'Login to Textpattern',
		'logout' => 'Logout',
		'log_in_button' => 'Login',
		'lv-lv' => 'Latviešu',
		'method' => 'Method',
		'modified' => 'modified',
		'nl-nl' => 'Nederlands',
		'no-no' => 'Norsk',
		'no_results_found' => 'No results found.',
		'password' => 'Password',
		'per_page' => 'per page',
		'pl-pl' => 'Polski',
		'pt-br' => 'Português (Brasil)',
		'pt-pt' => 'Português (Portugal)',
		'range' => 'Range',
		'restricted_area' => 'Restricted Area',
		'ro-ro' => 'Română',
		'ru-ru' => 'Русский',
		'save_new' => 'Save New',
		'showing_search_results' => 'Showing {from} to {to} of {total}',
		'site_slogan' => 'Site slogan',
		'sk-sk' => 'Slovenčina',
		'sort_value' => 'Sort Value',
		'stay_logged_in' => 'Remain logged in with this browser',
		'sticky' => 'Sticky',
		'structure' => 'Structure',
		'sv-se' => 'Svenska',
		'tab_admin' => 'Admin',
		'tab_comments' => 'Comments',
		'tab_content' => 'Content',
		'tab_diagnostics' => 'Diagnostics',
		'tab_extensions' => 'Extensions',
		'tab_file' => 'Files',
		'tab_forms' => 'Forms',
		'tab_image' => 'Images',
		'tab_import' => 'Import',
		'tab_link' => 'Links',
		'tab_list' => 'Articles',
		'tab_logs' => 'Visitor Logs',
		'tab_organise' => 'Categories',
		'tab_pages' => 'Pages',
		'tab_plugins' => 'Plugins',
		'tab_preferences' => 'Preferences',
		'tab_presentation' => 'Presentation',
		'tab_sections' => 'Sections',
		'tab_site_admin' => 'Users',
		'tab_style' => 'Style',
		'tab_view_site' => 'View Site',
		'tab_write' => 'Write',
		'th-th' => 'ไทย',
		'thumbnail' => 'Thumbnail',
		'title_body' => 'Title & Body',
		'title_body_excerpt' => 'Title, Body & Excerpt',
		'txpnl2br' => 'Line Breaks Only',
		'txprawxhtml' => 'Raw XHTML',
		'txpstriptags' => 'Strip Tags',
		'txptextile' => 'Textile',
		'txptextilelite' => 'Textile Lite',
		'txt_quote_double_close' => '”',
		'txt_quote_double_open' => '“',
		'txt_quote_single_close' => '’',
		'txt_quote_single_open' => '‘',
		'uk-ua' => 'Українська',
		'upload_err_cant_write' => 'Failed to write file to disk',
		'upload_err_extension' => 'File upload stopped by PHP extension',
		'upload_err_form_size' => 'File exceeds the maximum size specified in Textpattern’s preferences',
		'upload_err_ini_size' => 'File exceeds the upload_max_filesize directive in php.ini',
		'upload_err_no_file' => 'No file was specified',
		'upload_err_partial' => 'File was only partially uploaded',
		'upload_err_tmp_dir' => 'Missing a temporary folder, used by PHP to store uploaded files. Please consult your webhost.
',
		'upload_file' => 'Upload file',
		'use_textile' => 'Use Textile',
		'vi-vn' => 'Tiếng Việt (Việt Nam)',
		'viewsite' => 'View Site',
		'view_per_page' => 'View {page} per page',
		'visible' => 'Visible',
		'with_selected' => 'With selected:',
		'zh-cn' => '中文(简体)',
		'zh-tw' => '中文(繁體)',
	),
	'css' => array(
		'add_declaration' => 'add declaration',
		'add_new_selector' => 'Add new selector',
		'all_stylesheets' => 'All Styles',
		'bulkload_existing_css' => 'Create or load new style',
		'cannot_delete_default_css' => 'Style <strong>default</strong> cannot be deleted.',
		'copy_css_as' => '&#8230;or copy style as',
		'create_new_css' => 'Create new style',
		'css_already_exists' => 'Stylesheet <strong>{name}</strong> already exists.',
		'css_created' => 'Style <strong>{name}</strong> created.',
		'css_deleted' => 'Style <strong>{name}</strong> deleted.',
		'css_mode' => 'CSS Mode',
		'css_name_required' => 'Please provide a name for your style.',
		'css_property_value' => 'Property : Value',
		'css_selector' => 'Selector',
		'css_updated' => 'Style <strong>{name}</strong> updated.',
		'css_used_by_section' => 'Style <strong>{name}</strong> not deleted; used by {count} section(s).',
		'delete_declaration' => 'Delete this declaration',
		'delete_entire_selector' => 'Delete entire selector',
		'delete_this_declaration' => 'Delete this declaration',
		'edit_css' => 'Style',
		'edit_css_file' => 'edit CSS file',
		'edit_css_in_form' => 'Edit in CSS editor',
		'edit_raw_css' => 'Edit raw CSS',
		'name_for_this_style' => 'Name for this style',
		'property' => 'Property',
		'save_css_as' => 'Save style as:',
		'save_this_declaration' => 'Save this declaration',
		'save_this_selector' => 'Save this selector',
		'selector' => 'Selector',
		'style_sheet' => 'Style sheet',
		'style_sheet_saved' => 'Style sheet saved',
		'you_are_editing_css' => 'You are editing style',
	),
	'diag' => array(
		'active_plugins' => 'Active plugins',
		'all_checks_passed' => 'All checks passed!',
		'apache_modules' => 'Apache modules',
		'apache_version' => 'Apache version',
		'cleanurl_only_apache' => 'Clean URLs are only supported by Apache, use at your own risk.',
		'clean_url_test_failed' => 'Clean URL test failed.',
		'detail' => 'Detail',
		'dev_version_live' => 'You are running in-development files on a live server',
		'diagnostic_info' => 'Diagnostic info',
		'dir_not_writable' => '{dirtype} is not writable',
		'dns_lookup_fails' => 'Web Domain DNS lookup fails',
		'document_root' => 'Document root',
		'file_uploads_disabled' => 'File uploads are disabled',
		'gd_info' => '{version}; supported formats: {supported}.',
		'gd_library' => 'GD Image Library',
		'high' => 'High',
		'htaccess_contents' => '.htaccess file contents',
		'htaccess_missing' => '.htaccess file is missing',
		'img_dir_read_only' => 'Image directory is read-only',
		'is_inaccessible' => 'is inaccessible',
		'last_update' => 'Last Update',
		'low' => 'Low',
		'magic_quotes' => 'Magic quotes',
		'missing_files' => 'Missing files',
		'modified_files' => 'Some Textpattern files have been modified',
		'mod_rewrite_missing' => 'Apache module mod_rewrite is not installed',
		'old_files' => 'Some Textpattern files are out of date',
		'old_placeholder' => 'Old placeholder file is in the way',
		'os_version' => 'Server OS',
		'path_to_site_inacc' => '$path_to_site is inaccessible.',
		'php_extensions' => 'PHP extensions',
		'php_sapi_mode' => 'PHP Server API',
		'php_version' => 'PHP version',
		'preflight_check' => 'Pre-flight check',
		'register_globals' => 'Register globals',
		'rfc2616_headers' => 'RFC 2616 headers',
		'rfc_2616_headers' => 'CGI Header Mode',
		'server' => 'Server',
		'server_time' => 'Server Local Time',
		'site_trailing_slash' => 'Site URL has a trailing slash',
		'site_url_mismatch' => 'Site URL preference might be incorrect',
		'some_php_functions_disabled' => 'The following PHP functions (which may be necessary to run Textpattern) are disabled on your server',
		'still_exists' => 'still exists',
		'tmp_plugin_paths_match' => 'Temporary directory path and Plugin cache directory path should <strong>not</strong> match.',
		'txp_path' => 'Textpattern path',
		'txp_version' => 'Textpattern version',
		'warn_register_globals_or_update' => 'Your version of PHP has security related risks. Please turn register_globals off or update to a newer PHP version.',
		'web_domain' => 'Site URL',
	),
	'discuss' => array(
		'article_deleted' => 'Article deleted!',
		'ban' => 'Ban',
		'banned_for' => 'Banned For',
		'ban_author' => 'Ban comment author',
		'cant_ban_blank_ip' => 'You cannot ban a blank IP address.',
		'comments_deleted' => 'Comments deleted: <strong>{list}</strong>.',
		'comments_marked_spam' => 'Comments hidden and marked as spam: <strong>{list}</strong>.',
		'comments_marked_unmoderated' => 'Comments hidden and marked as unmoderated: <strong>{list}</strong>.',
		'comments_marked_visible' => 'Comments made visible: <strong>{list}</strong>.',
		'comment_not_found' => 'Comment does not exist, it may have been deleted.',
		'comment_updated' => 'Comment <strong>{id}</strong> updated.',
		'confirm_comment_deletion' => 'confirm comment deletion',
		'date_banned' => 'Date Banned',
		'displayed_comments' => 'Displayed comments',
		'edit_comment' => 'Edit Comment',
		'hide_comment' => 'Hide comment',
		'hide_spam' => 'Hide (spam)',
		'hide_unmoderated' => 'Hide (unmoderated)',
		'ips_banned' => 'IP addresses banned from commenting: <strong>{list}</strong>.',
		'ip_already_banned' => 'IP address <strong>{ip}</strong> already banned.',
		'ip_banned' => 'IP address <strong>{ip}</strong> banned.',
		'ip_ban_removed' => 'IP address <strong>{ip}</strong> ban removed.',
		'list_banned_ips' => 'List banned IPs',
		'list_discussions' => 'Comments',
		'name_used' => 'Name Used',
		'no_comments_recorded' => 'No comments recorded.',
		'no_ips_banned' => 'No IP addresses have been banned.',
		'show' => 'Show',
		'show_spam' => 'Show Spam',
		'spam' => 'Spam',
		'unban' => 'Unban',
		'unmoderated' => 'Unmoderated',
	),
	'file' => array(
		'condition' => 'Condition',
		'download' => 'Download',
		'downloads' => 'Downloads',
		'existing_file' => 'Existing file:',
		'file' => 'File',
		'file_already_exists' => 'File <strong>{name}</strong> already exists.',
		'file_cannot_rename' => 'File <strong>{name}</strong> could not be renamed.',
		'file_category' => 'Category',
		'file_deleted' => 'File(s) <strong>{name}</strong> deleted.',
		'file_delete_failed' => 'Failed to delete file(s)',
		'file_dir_not_writeable' => 'Warning: cannot write to file directory<br />{filedir}.',
		'file_download_count' => 'Download Count',
		'file_name' => 'Name',
		'file_not_found' => 'File(s) not found',
		'file_not_updated' => 'File <strong>{name}</strong> <em>not</em> updated!',
		'file_relink' => 'Upload/Assign File',
		'file_status' => 'File Status',
		'file_status_missing' => 'Missing',
		'file_status_ok' => 'Ok',
		'file_unsynchronized' => 'File <strong>{name}</strong> has become unsynchronized with the database. Please manually fix file name.',
		'file_updated' => 'File <strong>{name}</strong> updated.',
		'file_uploaded' => 'File <strong>{name}</strong> uploaded.',
		'file_upload_failed' => 'Failed to upload file',
		'invalid_filename' => 'Invalid filename',
		'invalid_id' => 'Invalid ID',
		'linked_to_file' => 'Linked record to file',
		'no_files_recorded' => 'No files recorded.',
		'permissions' => 'Permissions',
		'private' => 'Private',
		'public' => 'Public',
		'replace_file' => 'Replace file',
		'reset' => 'reset',
		'reset_file_count_failure' => 'Failed to reset file count',
		'reset_file_count_success' => 'Successfully reset file count',
	),
	'form' => array(
		'all_forms' => 'All forms',
		'create_new_form' => 'Create new form',
		'delete_form_confirmation' => 'confirm form deletion',
		'edit_forms' => 'Form Templates',
		'forms_deleted' => 'Forms deleted: <strong>{list}</strong>.',
		'form_already_exists' => 'Form <strong>{name}</strong> already exists.',
		'form_created' => 'Form <strong>{name}</strong> created.',
		'form_name' => 'Name (required)',
		'form_name_invalid' => 'Form name invalid.',
		'form_type' => 'Type (required)',
		'form_type_missing' => 'Form type is missing',
		'form_updated' => 'Form <strong>{name}</strong> updated.',
		'list_forms' => 'list forms',
		'you_are_editing_form' => 'You are editing form',
	),
	'image' => array(
		'add_magnify_icon' => 'Magnifier',
		'alt_text' => 'Alternate text',
		'cannot_write_directory' => 'Cannot write to directory',
		'choose_either_width_height_or_both' => 'Indicate width, height, or both',
		'create_thumbnail' => 'Create thumbnail',
		'edit_image' => 'Edit Image',
		'images' => 'Images',
		'image_deleted' => 'Image(s) <strong>{name}</strong> deleted.',
		'image_delete_failed' => 'Image(s) <strong>{name}</strong> could not be completely deleted.',
		'image_name' => 'Image name',
		'image_save_error' => 'There was a problem saving image data',
		'image_updated' => 'Image <strong>{name}</strong> updated.',
		'image_uploaded' => 'Image(s) <strong>{name}</strong> uploaded.',
		'img_dir_not_writeable' => 'Warning: cannot write to image directory<br />{imgdir}.',
		'invalid_width_or_height' => 'Invalid width or height',
		'keep_square_pixels' => 'Crop',
		'not_saved' => '<strong>not</strong> saved!',
		'no_images_recorded' => 'No images recorded.',
		'only_graphic_files_allowed' => 'Only .jpg, .gif, .png or .swf file types allowed.',
		'replace_image' => 'Replace image',
		'save_these_settings_as_default' => 'Save settings as default',
		'thumbnail_deleted' => 'Thumbnail deleted.',
		'thumbnail_not_saved' => 'Thumbnail <strong>{id}</strong> <em>not</em> saved!',
		'thumbnail_saved' => 'Thumbnail <strong>{id}</strong> saved.',
		'thumb_height' => 'Height',
		'thumb_width' => 'Width',
		'upload_category' => 'Category',
		'upload_dir_perms' => 'directory permissions need to be checked.',
		'upload_image' => 'Upload image',
		'upload_thumbnail' => 'Upload thumbnail',
	),
	'import' => array(
		'continue' => 'Continue',
		'database_stuff' => 'Database Data',
		'import_blogid' => 'Weblog ID',
		'import_database' => 'Database name',
		'import_file_not_found' => 'Import file not found. Please name the file import.txt and place it in /textpattern/include/import/',
		'import_host' => 'Mysql host',
		'import_invite' => 'Default comments invite',
		'import_login' => 'Mysql user',
		'import_password' => 'Mysql password',
		'import_section' => 'Section to import into',
		'import_status' => 'Default article status',
		'import_wpprefix' => 'Tables prefix (if any)',
		'select_tool' => 'Import from',
		'txp_import' => 'Import content from other publishing tools',
	),
	'link' => array(
		'edit_links' => 'Links',
		'linkcategory' => 'Link Categories',
		'links' => 'Links',
		'links_deleted' => 'Link(s) deleted: <strong>{list}</strong>.',
		'linktext' => 'linktext',
		'link_created' => 'Link <strong>{name}</strong> created.',
		'link_deleted' => 'Link <strong>{name}</strong> deleted.',
		'link_name' => 'Name',
		'link_saved' => 'Link saved.',
		'link_text' => 'Link text',
		'link_updated' => 'Link(s) <strong>{name}</strong> updated.',
		'no_links_recorded' => 'No links recorded.',
	),
	'list' => array(
		'article_modified' => 'Modified',
		'manage' => 'Manage',
	),
	'log' => array(
		'logs' => 'Logs',
		'logs_deleted' => 'Logs deleted: <strong>{list}</strong>.',
		'no_refers_recorded' => 'No referrers recorded.',
		'referrer' => 'Referrer',
		'visitor_logs' => 'Visitor Logs',
	),
	'page' => array(
		'all_pages' => 'All Pages',
		'copy_page_as' => '…or, copy page as',
		'create_new_page' => 'Create new page',
		'delete_page_confirmation' => 'confirm page deletion',
		'edit_page' => 'edit page',
		'edit_pages' => 'Page Templates',
		'page_already_exists' => 'Page <strong>{name}</strong> already exists.',
		'page_article_hed' => 'Article Output',
		'page_article_nav_hed' => 'Article Navigation',
		'page_created' => 'Page <strong>{name}</strong> created.',
		'page_deleted' => 'Page <strong>{name}</strong> deleted.',
		'page_misc_hed' => 'Miscellaneous',
		'page_name' => 'Page name (required)',
		'page_name_invalid' => 'Page name is invalid',
		'page_nav_hed' => 'Site Navigation',
		'page_updated' => 'Page <strong>{name}</strong> updated.',
		'page_used_by_section' => 'Page <strong>{name}</strong> not deleted; used by {count} section(s).',
		'page_xml_hed' => 'XML Feeds',
		'you_are_editing_div' => 'You are editing div',
		'you_are_editing_page' => 'You are editing page template',
	),
	'plugin' => array(
		'bad_plugin_code' => 'Badly formed or empty plugin code.',
		'broken_plugin' => 'broken',
		'changeorder' => 'Change order',
		'edit_plugins' => 'Plugins',
		'help' => 'Help',
		'install' => 'Install',
		'install_plugin' => 'Install plugin',
		'old_plugin' => 'Old-style (text file) plugin installer',
		'order' => 'Order',
		'plugin' => 'Plugin',
		'plugins' => 'Plugins',
		'plugin_compression_unsupported' => 'Plugin decompression is not supported by your server. Contact the plugin author for an uncompressed version.',
		'plugin_deleted' => 'Plugin <strong>{name}</strong> deleted.',
		'plugin_help' => 'Plugin Help',
		'plugin_installed' => 'Plugin <strong>{name}</strong> installed.',
		'plugin_install_failed' => 'Plugin <strong>{name}</strong> install <em>failed</em>!',
		'plugin_modified' => 'Modified',
		'plugin_prefs' => 'Options',
		'plugin_saved' => 'Plugin <strong>{name}</strong> updated.',
		'plugin_updated' => 'Plugin <strong>{name}</strong> updated.',
		'previewing_plugin' => 'Previewing plugin:',
	),
	'prefs' => array(
		'active_language' => 'Currently active language',
		'admin_side_plugins' => 'Use admin-side plugins?',
		'advanced_preferences' => 'Advanced',
		'allow_article_php_scripting' => 'Allow PHP in articles?',
		'allow_form_override' => 'Allow form override?',
		'allow_page_php_scripting' => 'Allow PHP in pages?',
		'allow_raw_php_scripting' => 'Allow raw PHP?',
		'all_hits' => 'All hits',
		'archive_dateformat' => 'Archive date format',
		'archive_date_case' => 'Archive date case',
		'archive_dir' => 'Archive directory',
		'articles_use_excerpts' => 'Articles use excerpts?',
		'attach_titles_to_permalinks' => 'Attach titles to permalinks?',
		'auto_dst' => 'Automatically adjust <abbr title="Daylight Saving Time">DST</abbr> setting?',
		'category_subcategory' => '/category/subcategory',
		'check_for_txp_updates' => 'Check Updates',
		'clean' => '/clean/',
		'comments_are_ol' => 'Present comments as a numbered list?',
		'comments_auto_append' => 'Automatically append comments to articles?',
		'comments_dateformat' => 'Comments date format',
		'comments_default_invite' => 'Default invite',
		'comments_disabled_after' => 'Disabled after',
		'comments_disallow_images' => 'Strip user images?',
		'comments_mode' => 'Comments mode',
		'comments_moderate' => 'Moderate comments?',
		'comments_on_default' => 'On by default?',
		'comments_require_email' => 'Require user’s e-mail address?',
		'comments_require_name' => 'Require user’s name?',
		'comments_sendmail' => 'Mail comments to author?',
		'comments_use_fat_textile' => 'Allow more Textile markup?',
		'comment_means_site_updated' => 'New comment means site updated?',
		'comment_nofollow' => 'Apply rel="nofollow" to comments?',
		'convert_linebreaks' => 'Convert linebreaks',
		'css' => 'Style',
		'custom' => 'Custom Fields',
		'custom_10_set' => 'Custom field 10 name',
		'custom_1_set' => 'Custom field 1 name',
		'custom_2_set' => 'Custom field 2 name',
		'custom_3_set' => 'Custom field 3 name',
		'custom_4_set' => 'Custom field 4 name',
		'custom_5_set' => 'Custom field 5 name',
		'custom_6_set' => 'Custom field 6 name',
		'custom_7_set' => 'Custom field 7 name',
		'custom_8_set' => 'Custom field 8 name',
		'custom_9_set' => 'Custom field 9 name',
		'czech' => 'Čeština',
		'danish' => 'Dansk',
		'default_event' => 'Default admin tab',
		'dutch' => 'Nederlands',
		'edit_preferences' => 'Preferences',
		'edit_raw_css_by_default' => 'Use raw editing mode by default?',
		'enable_xmlrpc_server' => 'Enable XML-RPC server?',
		'english_gb' => 'English (GB)',
		'english_us' => 'English (US)',
		'experts_only' => 'experts only',
		'expire_logs_after' => 'Logs expire after how many days?',
		'feeds' => 'Feeds',
		'file_base_path' => 'File directory path',
		'file_max_upload_size' => 'Maximum file size of uploads (in bytes)',
		'finnish' => 'Finnish',
		'french' => 'Français',
		'from_file' => 'Install From File',
		'from_server' => 'Install From Remote Server',
		'gmtoffset' => 'Time Zone',
		'ham' => 'All but spam',
		'hours_days_ago' => 'hrs/days ago',
		'id_title' => '/id/title',
		'img_dir' => 'Image directory',
		'include_email_atom' => 'Include e-mail in Atom feeds?',
		'install_langfile' => 'To install new languages from file you can download them from {url} and place them inside your ./textpattern/lang/ directory.',
		'install_language' => 'Install Language',
		'is_dst' => '<abbr title="Daylight Saving Time">DST</abbr> enabled?',
		'language' => 'Language',
		'lastmod_keepalive' => 'Compensate for persistent connections mod_deflate bug?',
		'leave_text_untouched' => 'Leave text untouched',
		'link' => 'Links',
		'locale' => 'Locale',
		'logging' => 'Logging',
		'logs_expire' => 'Logs expire after how many days?',
		'manage_languages' => 'Language',
		'markup_default' => 'Default Markup',
		'max_url_len' => 'Maximum URL length (in characters)',
		'mentions' => 'Mentions',
		'messy' => '?=messy',
		'never_display_email' => 'Hide e-mail address?',
		'new_textpattern_version_available' => 'There is a completely new Textpattern version available. Do you want to try it?',
		'norwegian' => 'Norwegian',
		'no_popup' => 'current window',
		'override_emailcharset' => 'Use ISO-8859-1 encoding in e-mails sent (default is UTF-8)?',
		'page_mode' => 'Page mode',
		'path_from_root' => 'Sub-directory (if any)',
		'path_to_site_missing' => '$path_to_site is not set (update index.php)',
		'permalink_title_format' => 'Permalink title-like-this (instead of TitleLikeThis)?',
		'permlink_mode' => 'Permanent link mode',
		'ping_textpattern_com' => 'Ping textpattern.com?',
		'ping_weblogsdotcom' => 'Ping ping-o-matic.com?',
		'plugin_cache_dir' => 'Plugin cache directory path',
		'polish' => 'Polish',
		'portuguese' => 'Portuguese',
		'preferences_saved' => 'Preferences saved',
		'prefs' => 'Prefs',
		'problem_connecting_rpc_server' => 'There is a problem trying to connect to the RPC server. Please, try again later.',
		'production_debug' => 'Debugging',
		'production_live' => 'Live',
		'production_status' => 'Production Status',
		'production_test' => 'Testing',
		'publish_expired_articles' => 'Publish expired articles?',
		'record_mentions' => 'Record mentions',
		'referrers_only' => 'Referrers only',
		'rpc_connect_error' => 'Can’t connect to remote server to check for updated language files. Please try again later.',
		'rss_how_many' => 'How many articles should be included in feeds?',
		'russian' => 'Russian',
		'scots' => 'Scots',
		'section_id_title' => '/section/id/title',
		'section_title' => '/section/title',
		'send_lastmod' => 'Send “Last-Modified” header?',
		'show_article_category_count' => 'Show article count on categories tab?',
		'show_comment_count_in_feed' => 'Show comment count in feeds?',
		'site_prefs' => 'Basic',
		'smtp_from' => 'SMTP envelope sender address',
		'spam_blacklists' => 'Spam blacklists (comma-separated)',
		'spanish' => 'Español',
		'swedish' => 'Swedish',
		'syndicate_body_or_excerpt' => 'Syndicate article excerpt <strong>only</strong>?',
		'tagalog' => 'Tagalog',
		'tempdir' => 'Temporary directory path',
		'textile_links' => 'Textile link descriptions by default?',
		'thai' => 'Thai',
		'theme_name' => 'Admin-side theme',
		'timeoffset' => 'Time offset (hours)',
		'title_no_widow' => 'Prevent widowed words in article titles?',
		'title_only' => '/title',
		'updated' => 'Updated',
		'updated_branch_version_available' => 'There is an update for this Textpattern version series (4.0.x) available.',
		'update_languages' => 'Update Languages',
		'urls_to_ping' => 'URLs to ping (comma-separated)',
		'url_mode' => 'URL mode',
		'use_comments' => 'Accept comments?',
		'use_dns' => 'Use DNS lookup in visitor logs?',
		'use_mail_on_feeds_id' => 'Use e-mail address to construct feed ids (default is site URL)?',
		'use_plugins' => 'Use plugins?',
		'year_month_day_title' => '/year/month/day/title',
	),
	'public' => array(
		'404_not_found' => 'The requested resource was not found.',
		'410_gone' => 'The requested resource is no longer available.',
		'ago' => 'ago',
		'all' => 'All',
		'already_exists' => 'already exists',
		'article' => 'article',
		'articles' => 'Articles',
		'articles_found' => 'articles found',
		'article_found' => 'article found',
		'atom_feed_title' => 'Atom Feed',
		'attribute_values_must_be_quoted' => 'Attribute values must be quoted',
		'author' => 'Author',
		'authors' => 'Authors',
		'a_few_seconds' => 'a few seconds',
		'blockquote' => 'Blockquote',
		'browse' => 'Browse',
		'bs-ba' => 'Bosanski (Bosna i Hercegovina)',
		'bulleted_list' => 'Bulleted list',
		'caption' => 'Caption',
		'categories' => 'Categories',
		'categorize' => 'Categorise',
		'category' => 'Category',
		'category1' => 'Category 1',
		'category2' => 'Category 2',
		'change' => 'change',
		'check_html' => 'Check HTML',
		'choose' => 'Choose…',
		'citation' => 'citation',
		'comment' => 'comment',
		'comments' => 'Comments',
		'comments_closed' => 'Commenting is closed for this article.',
		'comments_on' => 'Comments on',
		'comments_permlink' => 'Permanent link',
		'comment_comment' => 'Comment',
		'comment_email' => 'E-mail',
		'comment_email_required' => 'Please enter a valid e-mail address.',
		'comment_invitation' => 'Invitation',
		'comment_message' => 'Message',
		'comment_moderated' => 'Your comment is pending moderation. It will appear after it has been approved.',
		'comment_name' => 'Name',
		'comment_name_required' => 'Please enter your name.',
		'comment_posted' => 'Thank you for adding your comment.',
		'comment_received' => '[{site}] comment received: {title}',
		'comment_recorded' => 'A comment on your post "{title}" was recorded.',
		'comment_required' => 'Please enter a comment.',
		'comment_web' => 'Website',
		'contact' => 'Contact',
		'copy' => 'Copy',
		'create' => 'Create',
		'created' => 'created',
		'create_new' => 'Create new',
		'date' => 'Date',
		'dateformat' => 'Date format',
		'date_case' => 'Date case',
		'day' => 'day',
		'days' => 'days',
		'default' => 'Default',
		'delete' => 'Delete',
		'deleted' => 'deleted',
		'deleted_text' => 'deleted text',
		'deprecated_attribute' => '{name} attribute is deprecated',
		'deprecated_function' => 'function {name} is deprecated',
		'deprecated_function_with' => 'function {name} is deprecated: use {with} instead',
		'deprecated_tag' => 'tag is deprecated',
		'edit' => 'Edit',
		'email' => 'E-mail',
		'email_address' => 'E-mail address',
		'emphasis' => 'emphasis',
		'error_article_context' => 'Article tags cannot be used outside an article context',
		'error_comment_context' => 'Comment tags cannot be used outside a comment context',
		'error_file_context' => 'File tags cannot be used outside a file context',
		'error_link_context' => 'Link tags cannot be used outside a link context',
		'extensions' => 'Extensions',
		'foo_bar' => 'Testing for underscores issue',
		'forget' => 'Forget',
		'form' => 'Form',
		'forms' => 'Forms',
		'go' => 'Go',
		'go_content' => 'Go to content',
		'go_nav' => 'Go to navigation',
		'go_search' => 'Go to search',
		'go_to' => 'Go to',
		'header' => 'header',
		'home' => 'Home',
		'host' => 'Host',
		'hour' => 'hour',
		'hours' => 'hours',
		'hr' => 'horizontal rule',
		'hyperlink' => 'hyperlink',
		'image' => 'image',
		'imageurl' => 'imageurl',
		'inserted_text' => 'inserted text',
		'keywords' => 'Keywords',
		'label' => 'Label',
		'last_modification' => 'Last Modification',
		'linebreak' => 'line break',
		'list' => 'List',
		'list_articles' => 'List Articles',
		'list_categories' => 'list categories',
		'list_links' => 'list links',
		'live' => 'Live',
		'lowercase' => 'lowercase',
		'lt-lt' => 'Lietuvių',
		'manual' => 'Manual',
		'message' => 'Message',
		'message_deleted' => 'Message deleted',
		'message_preview' => 'Message Preview',
		'message_saved' => 'Message saved',
		'minute' => 'minute',
		'minutes' => 'minutes',
		'missing_article_tag' => 'Page template {page} does not contain a txp:article tag',
		'modified_by' => 'Last modified by',
		'month' => 'Month',
		'more' => 'More',
		'name' => 'Name',
		'never' => 'never',
		'newer' => 'Newer',
		'next' => 'Next',
		'no' => 'No',
		'none' => 'None',
		'nopopup' => 'nopopup',
		'numeric_list' => 'Numeric list',
		'off' => 'Off',
		'older' => 'Older',
		'on' => 'On',
		'only_articles_can_be_previewed' => 'Note: only article forms can be previewed.',
		'page' => 'Page',
		'pages' => 'Pages',
		'paragraph' => 'paragraph',
		'permanent_link' => 'Permanent link to this article',
		'permlink' => 'Permanent link',
		'plugin_load_error' => 'A problem occured while loading the plugin:',
		'plugin_load_error_above' => 'The above errors were caused by the plugin:',
		'popup' => 'popup',
		'post' => 'Post',
		'posted' => 'Posted',
		'posted_by' => 'Posted by',
		'prev' => 'Prev',
		'preview' => 'Preview',
		'publish' => 'Publish',
		'published_at' => 'Published at',
		'raw_php_deprecated' => 'Raw PHP tags are deprecated',
		'recently' => 'Recently',
		'recent_articles' => 'Recent Articles',
		'recent_posts' => 'Recent Posts',
		'remember' => 'Remember',
		'revert' => 'Revert',
		'rss_feed_title' => 'RSS Feed',
		'save' => 'Save',
		'saved' => 'saved',
		'save_button' => 'Save',
		'search' => 'Search',
		'search_results' => 'Search results',
		'select' => 'Select',
		'selected' => 'Selected',
		'site' => 'Site',
		'sitename' => 'Site name',
		'siteurl' => 'Site URL',
		'sp-rs' => 'Srpski',
		'sr-rs' => 'Српски',
		'status' => 'Status',
		'strong' => 'strong',
		'submit' => 'Submit',
		'subscript' => 'subscript',
		'superscript' => 'superscript',
		'tag_error' => 'Tag error: ',
		'textile_help' => 'Textile Help',
		'textile_lite_help' => 'Textile Lite Help',
		'text_conversion' => 'Text conversion',
		'text_handling' => 'Text handling',
		'time' => 'Time',
		'time_ago' => '{time} ago',
		'title' => 'Title',
		'tooltip' => 'Link tooltip',
		'tr-tr' => 'Türkçe',
		'type' => 'Type',
		'undefined' => 'Undefined',
		'unknown_attribute' => 'Unknown tag attribute: {att}',
		'unknown_image' => 'Unknown image.',
		'unknown_section' => 'Unknown section',
		'unknown_tag' => 'tag does not exist',
		'untitled' => 'Untitled',
		'update' => 'Update',
		'upload' => 'Upload',
		'uploaded' => 'uploaded',
		'url' => 'URL',
		'value' => 'Value',
		'version' => 'Version',
		'view' => 'View',
		'website' => 'Website',
		'week' => 'week',
		'weeks' => 'weeks',
		'yes' => 'Yes',
		'your_branch_is_updated' => 'You have the most updated version of this Textpattern branch',
		'your_ip_is_blacklisted_by' => 'Your IP address has been blacklisted by',
		'you_have_been_banned' => 'You have been banned from commenting.',
		'yyyy-mm' => 'yyyy-mm',
	),
	'section' => array(
		'delete_section_confirmation' => 'confirm section deletion',
		'edit_sections' => 'edit sections',
		'include_in_search' => 'Include in site search',
		'on_front_page' => 'On front page',
		'section' => 'Section',
		'sections' => 'Sections',
		'section_created' => 'Section <strong><a href="#section-{name}">{name}</a></strong> created.',
		'section_deleted' => 'Section <strong>{name}</strong> deleted.',
		'section_head' => 'Site Sections',
		'section_longtitle' => 'Section title',
		'section_name' => 'Section name',
		'section_name_already_exists' => 'Section <strong><a href="#section-{name}">{name}</a></strong> already exists.',
		'section_updated' => 'Section <strong><a href="#section-{name}">{name}</a></strong> updated.',
		'section_used_by_article' => 'Section <strong>{name}</strong> not deleted; used by {count} article(s).',
		'selected_by_default' => 'Selected by default',
		'style' => 'Style',
		'syndicate' => 'Syndicate?',
		'uses_page' => 'Uses page',
		'uses_style' => 'Uses style',
	),
	'setup' => array(
		'about_to_create' => 'You are about to create and populate database tables.',
		'already_installed' => 'Looks like Textpattern is already installed. If you want to make a clean install, please remove <code>config.php</code> from your <code>/textpattern/</code> directory and try again.',
		'before_you_proceed' => 'Before you proceed',
		'checking_database' => 'Checking database connection…',
		'choose_password' => 'Choose a password',
		'confirm_site_path' => 'Please confirm the following path',
		'create_config' => 'Create a file called <code>config.php</code> in the <code>/textpattern/</code> directory and paste the following inside:',
		'database_engine' => 'Database engine',
		'db_cant_connect' => 'Can’t connect to database',
		'db_connected' => 'Connected',
		'db_doesnt_exist' => 'Database {dbname} does not exist or your specified user does not have permission to access it.',
		'db_must_exist' => 'Note that the database you specify must already exist, Textpattern will not create it.',
		'did_it' => 'I did it',
		'email_required' => 'Please provide a valid e-mail address.',
		'errors_during_install' => 'There were {num} errors during the installation. You can ask for help in the Textpattern forums.',
		'full_path_to_txp' => 'Full server path to Textpattern',
		'mysql' => 'MySQL',
		'mysqli' => 'MySQLi',
		'mysql_database' => 'MySQL database',
		'mysql_login' => 'MySQL login',
		'mysql_password' => 'MySQL password',
		'mysql_server' => 'MySQL server',
		'my_site' => 'My Site',
		'my_slogan' => 'My pithy slogan',
		'need_details' => 'Inevitably, we need a few details',
		'pdo_sqlite' => 'SQLite',
		'please_enter_url' => 'Please enter the web-reachable address of your site',
		'postgresql' => 'PostgreSQL',
		'prefix_bad_characters' => 'The table prefix {dbprefix} contains characters that are not allowed.<br /> The first character must match one of <b>a-zA-Z_</b> and all following characters must match one of <strong>a-zA-Z0-9_</strong>',
		'prefix_warning' => '(Use <strong>only</strong> if you require multiple installations in one database)',
		'setup_comment_invite' => 'Comment',
		'setup_login' => 'Choose a login name (only basic characters and spaces please)',
		'set_temp_dir_prefs' => 'Sorry, but we failed to find a writable directory to hold temporary files.<br />Please visit the &#8220;Advanced Preferences&#8221; tab and adjust the &#8220;Temporary directory path&#8221; setting to suit your needs.',
		'site_path' => 'Site path',
		'site_url' => 'Site URL',
		'table_prefix' => 'Table prefix',
		'thanks' => 'Thank you.',
		'thanks_for_interest' => 'Thank you for your interest in Textpattern.',
		'that_went_well' => 'That went well. Database tables were created and populated.',
		'using_db' => 'Using {dbname}',
		'warn_mail_unavailable' => 'Your PHP installation is missing the mail() function. Therefore no emails can be sent from Textpattern, which limits certain functionality.',
		'welcome_to_textpattern' => 'Welcome to Textpattern',
		'your_email' => 'Your e-mail address',
		'your_full_name' => 'Your full name',
		'you_can_access' => 'You should be able to access the <a href="index.php">main interface</a> with the login and password you chose.',
	),
	'tag' => array(
		'active_class' => 'CSS class for active list item',
		'align' => 'Alignment',
		'allowoverride' => 'Allow form to be overridden?',
		'article_divider' => 'Article divider',
		'breadcrumb_linked' => 'Link breadcrumbs?',
		'breadcrumb_separator' => 'Breadcrumbs separator',
		'break' => 'List break tag',
		'breakclass' => 'CSS class for list break tag',
		'build' => 'Build Tag',
		'button_text' => 'Button text',
		'category_list_section' => 'Link to specific section?',
		'category_tags' => 'Category',
		'class' => 'CSS class',
		'comments_form' => 'Comments Form',
		'comment_details' => 'Comment Details',
		'comment_form' => 'Comment Form',
		'comment_name_link' => 'Link to commenter’s e-mail address/website?',
		'decimals' => 'Display # numbers after the decimal point',
		'default_title' => 'Text to use for default section link',
		'escape' => 'Escape',
		'exclude' => 'Exclude',
		'filename' => 'Name',
		'file_download_tags' => 'File Downloads',
		'flavor' => 'Syndication format',
		'flavour' => 'Syndication format',
		'format' => 'Format',
		'gmt' => 'Format according to GMT time?',
		'has_excerpt' => 'Has excerpt',
		'hilight' => 'Highlight tag',
		'hilight_limit' => 'Highlight how many instances?',
		'html_id' => 'Id XHTML attribute',
		'id' => 'ID#',
		'include_default' => 'Include default section?',
		'inline_style' => 'Inline style (CSS)',
		'input_size' => 'Input size',
		'isize' => 'Input size',
		'labeltag' => 'Label tag',
		'limit' => 'Display how many?',
		'linkclass' => 'CSS class for links',
		'link_to_this_author' => 'Link to a list of other articles by this author?',
		'link_to_this_category' => 'Link to a list of other articles in this category?',
		'link_to_this_section' => 'Link to a list of other articles in this section?',
		'listform' => 'List form',
		'match' => 'How are they related?',
		'media' => 'Media XHTML attribute',
		'msgcols' => 'Message textarea columns',
		'msgrows' => 'Message textarea rows',
		'n' => 'Name',
		'next_page_link' => 'Next page link',
		'no_categories_available' => 'No categories available.',
		'no_forms_available' => 'No forms available.',
		'no_sections_available' => 'No sections available.',
		'offset' => 'Skip',
		'pageby' => 'Paginate by',
		'page_file_hed' => 'File Downloads',
		'pgonly' => 'Count articles, but show nothing',
		'random' => 'Random',
		'rel' => 'Rel XHTML attribute',
		'searchall' => 'Search all sections?',
		'searchsticky' => 'Search sticky articles?',
		'search_input_form' => 'Search input',
		'search_results_form' => 'Search Results',
		'section_tags' => 'Section',
		'showalways' => 'Show always',
		'showcount' => 'Show count?',
		'size_format' => 'Size format',
		'sort' => 'Sort by',
		'sort_by' => 'Sort by',
		'sort_direction' => 'Sort direction',
		'tag' => 'Tag',
		'tagbuilder' => 'Tag Builder',
		'tags' => 'Tags',
		'tag_article' => 'Articles (Single or List)',
		'tag_article_custom' => 'Articles (Custom List)',
		'tag_article_image' => 'Article Image',
		'tag_author' => 'Author',
		'tag_body' => 'Body',
		'tag_body_excerpt' => 'Body Excerpt',
		'tag_breadcrumb' => 'Breadcrumb',
		'tag_category' => 'Category',
		'tag_category1' => 'Category 1',
		'tag_category2' => 'Category 2',
		'tag_category_list' => 'Category List',
		'tag_comments' => 'Comments',
		'tag_comments_form' => 'Comments Form',
		'tag_comments_invite' => 'Comments Invite',
		'tag_comments_preview' => 'Comments Preview',
		'tag_comment_anchor' => 'Comment Anchor',
		'tag_comment_email' => 'Comment E-mail',
		'tag_comment_email_input' => 'Comment E-mail Input',
		'tag_comment_id' => 'Comment ID',
		'tag_comment_message' => 'Comment Message',
		'tag_comment_message_input' => 'Comment Message Input',
		'tag_comment_name' => 'Comment Name',
		'tag_comment_name_input' => 'Comment Name Input',
		'tag_comment_permlink' => 'Comment Permanent Link',
		'tag_comment_preview' => 'Comment Preview Button',
		'tag_comment_remember' => 'Remember Details Checkbox',
		'tag_comment_submit' => 'Comment Submit Button',
		'tag_comment_time' => 'Comment Time',
		'tag_comment_web' => 'Comment Website',
		'tag_comment_web_input' => 'Comment Web Input',
		'tag_css' => 'CSS Link (Head)',
		'tag_email' => 'E-mail Link (Spam-Proof)',
		'tag_excerpt' => 'Excerpt',
		'tag_feed_link' => 'Articles Feed Link',
		'tag_file_download' => 'File Download',
		'tag_file_download_category' => 'File Category',
		'tag_file_download_created' => 'File Created Time',
		'tag_file_download_description' => 'File Description',
		'tag_file_download_downloads' => 'File Download Count',
		'tag_file_download_id' => 'File ID#',
		'tag_file_download_link' => 'File Download Link',
		'tag_file_download_list' => 'File Download List',
		'tag_file_download_modified' => 'File Modified Time',
		'tag_file_download_name' => 'File Name',
		'tag_file_download_size' => 'File Size',
		'tag_home' => 'Home',
		'tag_if_category' => 'If Category',
		'tag_if_section' => 'If Section',
		'tag_image' => 'Image',
		'tag_inline_' => 'Inline at end',
		'tag_lang' => 'Language',
		'tag_link' => 'Link',
		'tag_linkdesctitle' => 'Link, title=Description',
		'tag_linklist' => 'Links List',
		'tag_link_category' => 'Link Category',
		'tag_link_date' => 'Link Date',
		'tag_link_description' => 'Link Description',
		'tag_link_feed_link' => 'Links Feed Link',
		'tag_link_name' => 'Link Name',
		'tag_link_text' => 'Link Name',
		'tag_link_to_home' => 'Homepage Link',
		'tag_link_to_next' => 'Next Article Link',
		'tag_link_to_prev' => 'Previous Article Link',
		'tag_message' => 'Message',
		'tag_name' => 'Commenter name',
		'tag_newer' => 'Newer Articles Link',
		'tag_next_article' => 'Next article',
		'tag_next_title' => 'Next Article Title',
		'tag_older' => 'Older Articles Link',
		'tag_output_form' => 'Output Form',
		'tag_page_title' => 'Page Title',
		'tag_paging_link' => 'Next Page Link',
		'tag_password_protect' => 'Password Protection',
		'tag_permlink' => 'Permanent Link',
		'tag_popup' => 'Popup List',
		'tag_posted' => 'Posted',
		'tag_prev_article' => 'Previous article',
		'tag_prev_title' => 'Previous Article Title',
		'tag_recent_articles' => 'Recent Articles',
		'tag_recent_comments' => 'Recent Comments',
		'tag_related_articles' => 'Related Articles',
		'tag_search_input' => 'Search Input Form',
		'tag_search_result_date' => 'Search Result Date',
		'tag_search_result_excerpt' => 'Search Result Excerpt',
		'tag_search_result_title' => 'Search Result Title',
		'tag_search_result_url' => 'Search Result URL',
		'tag_section' => 'Section',
		'tag_section_list' => 'Section List',
		'tag_sitename' => 'Site Name',
		'tag_site_name' => 'Site Name',
		'tag_site_slogan' => 'Site Slogan',
		'tag_title' => 'Title',
		'tag__inline' => 'Inline at beginning',
		'textonly' => 'Text only?',
		'text_or_tag' => '* text or tag here *',
		'this_section' => 'Link to current section?',
		'time_any' => 'Any',
		'time_format' => 'Time format string',
		'time_future' => 'Future',
		'time_past' => 'Past',
		'title_separator' => 'Individual article and site name separator',
		'useful_tags' => 'Useful Tags',
		'use_thumbnail' => 'Use thumbnail?',
		'wraptag' => 'Wrap tag',
	)
);
$lastmod = gmdate('Y-m-d H:m:s',1249014846);
?>